==> haskell-x509-1.7.5-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.5
id: x509-1.7.5-KqQg6Mi5Sp6LnkmIY5JGw2
key: x509-1.7.5-KqQg6Mi5Sp6LnkmIY5JGw2
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer. please see README
category: Data
abi: 8c1096409822dee3b92e1a6df41756f7
exposed: True
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-1.7.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-1.7.5
hs-libraries: HSx509-1.7.5-KqQg6Mi5Sp6LnkmIY5JGw2
depends:
    asn1-encoding-0.9.5-EB58EapF6z449w8t1NTabZ
    asn1-parse-0.9.4-8cyIiT2t6vUHTYMFQpCtRh
    asn1-types-0.3.3-7z9CB8aq8VCJkGLUUe9y5o base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    hourglass-0.2.12-4t18e4DSgpnCTiyj5r8NVd
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth mtl-2.2.2
    pem-0.2.4-HncI1C63b9A2toAOPYDKsd
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.5-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.5
id: x509-1.7.5-C3bTySPvCifVV0W9F9BQx
key: x509-1.7.5-C3bTySPvCifVV0W9F9BQx
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer. please see README
category: Data
abi: 3602dd4e6b8da8fe6d9975c728104136
exposed: True
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-1.7.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-1.7.5
hs-libraries: HSx509-1.7.5-C3bTySPvCifVV0W9F9BQx
depends:
    asn1-encoding-0.9.6-IOecD5h1VTO2e6wAGqxYer
    asn1-parse-0.9.4-8Duvwvi8W6IKNdfs9Uokt7
    asn1-types-0.3.3-7z9CB8aq8VCJkGLUUe9y5o base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    hourglass-0.2.12-4t18e4DSgpnCTiyj5r8NVd
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth mtl-2.2.2
    pem-0.2.4-HncI1C63b9A2toAOPYDKsd
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
